/***************************************************************************
 $RCSfile$
                             -------------------
    cvs         : $Id: qbanking_p.h 764 2006-01-13 14:00:00Z cstim $
    begin       : Mon Mar 01 2004
    copyright   : (C) 2004 by Martin Preuss
    email       : martin@libchipcard.de

 ***************************************************************************
 *          Please see toplevel file COPYING for license details           *
 ***************************************************************************/

#ifndef QBANKING_BANKING_P_H
#define QBANKING_BANKING_P_H


#include <aqbanking/banking.h>
#include "qbanking.h"


#endif /* QBANKING_BANKING_P_H */


